@@ -37,8 +37,6 @@ def test_lazy_data_loading_inplace_load_some(ufo_UbuTestData):
     ufo.data["com.github.fonttools.ttx/T_S_I__0.ttx"] = some_data
     ufo.save()
     assert all(
-        v is _NOT_LOADED
-        for k, v in ufo.data._data.items()
-        if "T_S_I__0" not in k
+        v is _NOT_LOADED for k, v in ufo.data._data.items() if "T_S_I__0" not in k
     )
     assert ufo.data["com.github.fonttools.ttx/T_S_I__0.ttx"] == some_data
